@@ -1,5 +1,5 @@
 package Mail::DMARC;
-our $VERSION = '1.20170222'; # VERSION
+our $VERSION = '1.20170906'; # VERSION
 use strict;
 use warnings;
 
@@ -292,7 +292,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20170222
+version 1.20170906
 
 =head1 SYNOPSIS
 
@@ -616,7 +616,7 @@ Davide Migliavacca <shari@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Benny Pedersen Jean Paul Galea Making GitHub Delicious. Marc Bradshaw Priyadi Iman Nurcahyo Ricardo Signes
+=for stopwords Benny Pedersen ColocateUSA.net Jean Paul Galea Making GitHub Delicious. Marc Bradshaw Priyadi Iman Nurcahyo Ricardo Signes
 
 =over 4
 
@@ -626,6 +626,10 @@ Benny Pedersen <me@junc.eu>
 
 =item *
 
+ColocateUSA.net <company@colocateusa.net>
+
+=item *
+
 Jean Paul Galea <jeanpaul@yubico.com>
 
 =item *
@@ -646,6 +650,10 @@ Priyadi Iman Nurcahyo <priyadi@priyadi.net>
 
 =item *
 
+Priyadi Iman Nurcahyo <priyadi@users.noreply.github.com>
+
+=item *
+
 Ricardo Signes <rjbs@cpan.org>
 
 =item *
